##  How to Model an Enterprise Service Bus (ESB)
This approach helps you model the Enterprise Service Bus and microservices. SAP LeanIX recommends always modeling this from the business perspective. However, you can model this in much more detail with the caveat that you need to manage more data. As you can see, the approach is similar to how we model interfaces for middleware.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e36f07a4410149047bfee6e70144e_LowRes.png)
Then, you can introduce more complexity and information in the modeling to have a more detailed view of the technical interfaces and data flow.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274161d17a4410148ecdb384ab1f5064_LowRes.png)
